import { join } from 'path';
// eslint-disable-next-line import/no-unresolved
import { pathExists, writeJSON } from 'fs-extra/esm';

const fileName = (name) => [name, '.json'].join('');

export const generateMetadata = async ({
  constants: { PUBLISH_DIR: dest },
  packageJson,
  utils: { build },
}) => {
  const { version } = packageJson;
  const url = process.env.DEPLOY_URL;

  if (!version || !url) return null;

  const metadata = { versions: { [`v${version}`]: url } };
  const file = fileName('metadata');

  try {
    await writeJSON(join(dest, file), metadata);

    console.log(`Generated ${file}`);
  } catch (error) {
    build.failPlugin(`Failed to generate ${file}`, { error });
  }
};

export const generateStories = async ({
  constants: { PUBLISH_DIR: dest },
  utils: { build, run },
}) => {
  const file = fileName('stories');

  if (await pathExists(join(dest, file))) {
    console.log(`Existing ${file} found`);
  } else {
    try {
      await run.command(`npx sb extract ${dest}`);
      console.log(`Generated ${file}`);
    } catch (error) {
      build.failPlugin(`Failed to generate ${file}`, { error });
    }
  }
};
